.. _sphinxmod:

==============
Sphinx modules
==============

docubox bundles many sphinx-doc extension modules.

Themes
======

* bootstrap
* sphinx_rtd_theme

Parser
======

* MyST-Parser

Contrib modules
===============

* sphinxemoji
* sphinxcontrib-ditaa
* sphinxcontrib-drawio
* sphinxcontrib-httpdomain
* sphinxcontrib-imagesvg
* sphinxcontrib-openapi
* sphinxcontrib-plantuml
* sphinxcontrib-svgbob
* sphinxcontrib-redoc
* sphinxcontrib-xlsxtable
* sphinxcontrib-websupport
* sphinxcontrib-youtube
